# Predefined Field

A PredefinedField object stores the non-propagating data of a predefined field as well as a number of instances of the corresponding PredefinedFieldState object. The PredefinedFieldState object stores the propagating data of the predefined field in a single step. A specific type of PredefinedField object and a specific type of PredefinedFieldState object are designed for each type of predefined field. Instances of the PredefinedFieldState object are created and deleted internally by its corresponding PredefinedField object.

## Create predefined fields

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.PredefinedFieldModel.PredefinedFieldModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Classes

### Field

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.Field.Field
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldState

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.FieldState.FieldState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PredefinedField

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.PredefinedField.PredefinedField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PredefinedFieldState

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.PredefinedFieldState.PredefinedFieldState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FluidCavityPressure

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.FluidCavityPressure.FluidCavityPressure
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IMAField

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.IMAField.IMAField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IMARegion

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.IMARegion.IMARegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### InitialState

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.InitialState.InitialState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### KinematicHardening

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.KinematicHardening.KinematicHardening
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MaterialAssignment

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.MaterialAssignment.MaterialAssignment
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Temperature

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.Temperature.Temperature
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TemperatureState

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.TemperatureState.TemperatureState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TiffOptions

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.TiffOptions.TiffOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Velocity

```{eval-rst}
.. autoclass:: abaqus.PredefinedField.Velocity.Velocity
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
